@@ -37,9 +37,29 @@ def crosssection_elastic(g: float, T: float, idata: np.ndarray, rig_sphere: bool
         The VSS or rigid sphere crosssection
     """
     if rig_sphere:
-        return raw_crosssection_rigid_sphere(idata[1])
+        return raw_crosssection_elastic_rigid_sphere(idata[1])
     else:
-        return raw_crosssection_VSS(g, T, idata[9], idata[10])
+        return raw_crosssection_elastic_VSS(g, T, idata[9], idata[10])
+
+
+def elastic_collision_time(T: float, idata: np.ndarray, n: float):
+    """
+    Calculates the elastic collision time using the VSS crosssection
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    n : float
+        the numeric density of the mixture
+
+    Returns
+    -------
+        The elastic collision time
+    """
+    return raw_elastic_collision_time(T, idata[0], idata[9], idata[10], n)
 
 
 def crosssection_vt_fho(g: float, T: float, idata: np.ndarray, molecule: Molecule, i: int, delta: int,
@@ -592,7 +612,7 @@ def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: Molecule, molecul
                                   molecule2.num_rot, full_integral, rig_sphere, nokt)
 
 
-def raw_crosssection_VSS(g: float, T: float, vssc: float, vsso: float) -> float:
+def raw_crosssection_elastic_VSS(g: float, T: float, vssc: float, vsso: float) -> float:
     """Calculates the VSS crosssection, *raw* version
 
     Parameters
@@ -613,7 +633,7 @@ def raw_crosssection_VSS(g: float, T: float, vssc: float, vsso: float) -> float:
     return vssc * (T ** (-vsso)) * (g ** (2 - vsso))
 
 
-def raw_crosssection_rigid_sphere(sigma: float) -> float:
+def raw_crosssection_elastic_rigid_sphere(sigma: float) -> float:
     """Calculates the rigid sphere crosssection, *raw* version
 
     Parameters
@@ -629,6 +649,31 @@ def raw_crosssection_rigid_sphere(sigma: float) -> float:
     return constants.pi * (sigma ** 2)
 
 
+def raw_elastic_collision_time(T: float, mass: float, vssc: float, vsso: float, n: float):
+    """
+    Calculates the elastic collision time using the VSS crosssection, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+    n : float
+        the numeric density of the mixture
+
+    Returns
+    -------
+        The elastic collision time
+    """
+    return 1.0 / (vssc * n * ((8 * constants.k * T / (constants.pi * mass)) ** 0.5) * (T ** -vsso) * gamma(2 - vsso)
+                       * (constants.physical_constants['Angstrom star'][0] ** 2))
+
+
 def raw_crosssection_vt_fho(g: float, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
                             ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
                             delta: int, rig_sphere: bool=False) -> float:
@@ -671,10 +716,10 @@ def raw_crosssection_vt_fho(g: float, T: float, sigma: float, mass: float, beta:
     """
     if rig_sphere:
         return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
-               * raw_crosssection_rigid_sphere(sigma)
+               * raw_crosssection_elastic_rigid_sphere(sigma)
     else:
         return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
-               * raw_crosssection_VSS(g, T, vssc, vsso)
+               * raw_crosssection_elastic_VSS(g, T, vssc, vsso)
 
 
 def raw_crosssection_vv_fho(g, T: float, sigma: float, mass: float, beta: float, vssc: float, vsso: float,
@@ -721,10 +766,10 @@ def raw_crosssection_vv_fho(g, T: float, sigma: float, mass: float, beta: float,
     """
     if rig_sphere:
         return prob.vv_probability_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
-               * raw_crosssection_rigid_sphere(sigma)
+               * raw_crosssection_elastic_rigid_sphere(sigma)
     else:
         return prob.vv_probability_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
-               * raw_crosssection_VSS(g, T, vssc, vsso)
+               * raw_crosssection_elastic_VSS(g, T, vssc, vsso)
 
 
 def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecule_vibr: float,
