@@ -231,11 +231,11 @@ class Molecule(Particle):
             except IOError:
                 print('File with vibrational energies not found, will use anharmonic oscillator model')
                 self.vibr_model = 'anharmonic'
-                self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc * self.hvc)
+                self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc)
                 self.vibr = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
 
         elif self.vibr_model == 'anharmonic':
-            self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc * self.hvc)
+            self.vibr_zero = 0.5 * self.hvc * (1 - 0.5 * self.avc)
             self.vibr = self.hvc * (1.0 - self.avc) * a - self.hvc * self.avc * (a ** 2)
         elif self.vibr_model == 'harmonic':
             self.vibr_zero = 0.5 * self.hvc
@@ -623,6 +623,7 @@ class MoleculeMultiT(MoleculeQuasi):
         self._current_n = n_c
         self._current_T1 = T1
         self._current_T = T
+        self._current_kT = constants.k * T
 
     def num_vibr_levels(self, T: float, T1: float, true_amt: bool=True) -> int:
         """Returns the amount of vibrational levels (either the maximum one or current one)
