@@ -69,9 +69,10 @@ def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mo
                                              molecule.diss)
 
 
-def diss_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, i: int,
-                               center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the state-to-state non-equilibrium dissociation rate constant using the rigid-sphere crosssection
+def diss_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, i: int,
+                           center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+    """Calculates the state-to-state non-equilibrium dissociation rate constant using the generalized
+    omega integral over the rigid-sphere crosssection
 
     Parameters
     ----------
@@ -149,9 +150,10 @@ def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mol
                                                 molecule.vibr[i], molecule.diss)
 
 
-def rec_rate_rigid_sphere_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom, i: int,
+def rec_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom, i: int,
                               center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the state-to-state recombination rate constant using the rigid-sphere crosssection
+    """Calculates the state-to-state recombination rate constant using the generalized
+    omega integral over the rigid-sphere crosssection
 
     Parameters
     ----------
@@ -237,10 +239,10 @@ def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molec
         return res / molecule.Z_vibr(T)
 
 
-def diss_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi,
-                           center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the multi(one)-temperature non-equilibrium dissociaiton rate constant using the
-    rigid-sphere crosssection
+def diss_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi,
+                       center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+    """Calculates the multi(one)-temperature non-equilibrium dissociation rate constant using the generalized
+    omega integral over the rigid-sphere crosssection
 
     Parameters
     ----------
@@ -333,9 +335,10 @@ def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecu
         return res
 
 
-def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
-                          center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the averaged recombination rate constant using the rigid-sphere crosssection
+def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
+                      center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+    """Calculates the averaged recombination rate constant using the generalized
+    omega integral over the rigid-sphere crosssection
 
     Parameters
     ----------
@@ -489,8 +492,7 @@ def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
     mass_atom2 : float
         the mass of the second atom product of dissociation
     molecule_vibr : float
-        the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value) (with no offset)
+        the dimensional vibrational energy of the level from which the molecule dissociates (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which dissociates (with no offset)
 
