@@ -14,6 +14,39 @@ from .particles import Particle, Molecule
 import numpy as np
 
 
+def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
+                     n: float, infcoll: float, model: str='VSS') -> float:
+    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
+        the molecule for which the rotational relaxation time is being calculated
+    n : float
+        the numeric density of the mixture
+    infcoll : float
+        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
+    model : str
+        the interaction model to be used, possible values:
+            * 'VSS' (Variable Soft Sphere model)
+            * 'VHS' (Variable Hard Sphere model)
+            * the rigid sphere model will be used otherwise
+
+        defaults to `'VSS'`
+
+    Returns
+    -------
+    float
+        Rotational relaxation time
+    """
+    return raw_rot_rel_time_VSS(T, idata[0], molecule.LJe, idata[9], idata[10], idata[11], idata[12],
+                                molecule.mass, n, infcoll, model)
+
+
 def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infcoll: float,
                  model: str='ESA', Zr_model: str='VSS') -> float:
     """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
@@ -54,8 +87,8 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
     float
         Rotational relaxation time
     """
-    return raw_rot_rel_time(T, omega(T, 2, 2, idata, model=model, nokt=False), n,
-                            raw_Zr(T, idata[0], molecule.LJe, idata[6], idata[11], idata[12], molecule.mass, infcoll,
+    return raw_rot_rel_time(omega(T, 2, 2, idata, model=model, nokt=False), n,
+                            raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass, infcoll,
                                    Zr_model))
 
 
@@ -97,39 +130,6 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: P
                                                  molecule.num_rot, n, rig_sphere)
 
 
-def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
-                     n: float, infcoll: float, model: str='VSS') -> float:
-    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
-    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
-        the molecule for which the rotational relaxation time is being calculated
-    n : float
-        the numeric density of the mixture
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
-    model : str
-        the interaction model to be used, possible values:
-            * 'VSS' (Variable Soft Sphere model)
-            * 'VHS' (Variable Hard Sphere model)
-            * the rigid sphere model will be used otherwise
-
-        defaults to `'VSS'`
-
-    Returns
-    -------
-    float
-        Rotational relaxation time
-    """
-    return raw_rot_rel_time_VSS(T, idata[0], molecule.LJe, idata[5], idata[6], idata[11], idata[12],
-                                molecule.mass, n, infcoll, model)
-
-
 def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models
 
@@ -156,7 +156,7 @@ def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: s
     float
         Amount of collisions needed to reach rotational equilibrium
     """
-    return raw_Zr(T, idata[0], molecule.LJe, idata[6], idata[11], idata[12], molecule.mass, infcoll, model)
+    return raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass, infcoll, model)
 
 
 def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) -> float:
@@ -181,14 +181,58 @@ def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) ->
     return raw_millikan_white(T, idata[0], molecule.hvc, p)
 
 
-def raw_rot_rel_time(T: float, omega_integral: float, n: float, Zr) -> float:
-    """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral,
+def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: float, vsso: float, vssc_deflection: float,
+                         vsso_deflection: float, mass: float, n: float, infcoll: float, model: str='VSS') -> float:
+    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula,
     *raw* version
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
+    collision_mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    eps : float
+        the Lennard-Jones epsilon parameter :math:`\\varepsilon_{cd}`, divided by Boltzmann's constant
+    vssc : float
+        the :math:`C` parameter for the VSS model for the total cross-section
+    vsso : float
+        the :math:`\\omega` parameter for the VSS model for the total cross-section
+    vssc_deflection : float
+        the :math:`C` parameter for the VSS model for the deflection angle
+    vsso_deflection : float
+        the :math:`\\omega` parameter for the VSS model for the deflection angle
+    mass : float
+        the mass of the molecule for which the rotational relaxation time is being calculated
+    n : float
+        the numeric density of the mixture
+    infcoll : float
+        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
+    model : str
+        the interaction model to be used, possible values:
+            * 'VSS' (Variable Soft Sphere model)
+            * 'VHS' (Variable Hard Sphere model)
+            * the Rigid Sphere model will be used otherwise
+
+        defaults to `'VSS'`
+
+    Returns
+    -------
+    float
+        Rotational relaxation time
+    """
+    return raw_Zr(T, collision_mass, eps, vsso, vssc_deflection, vsso_deflection, mass,
+                  infcoll, model) / ((vssc * n * ((8 * constants.k * T / (constants.pi * collision_mass)) ** 0.5)
+                                      * (T ** -vsso) * gamma(2 - vsso))
+                                     * (constants.physical_constants['Angstrom star'][0] ** 2))
+
+
+def raw_rot_rel_time(omega_integral: float, n: float, Zr: float) -> float:
+    """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral,
+    *raw* version
+
+    Parameters
+    ----------
     omega_integral : float
         the value of the dimensional :math:`\\Omega^{(2,2)}` integral to be used in the calculation
     n : float
@@ -201,7 +245,7 @@ def raw_rot_rel_time(T: float, omega_integral: float, n: float, Zr) -> float:
     float
         Rotational relaxation time
     """
-    return 0.15625 * (constants.pi ** 2) * Zr / (n * omega_integral)  # 0.15625 is 5 / 32
+    return 0.15625 * constants.pi * Zr / (n * omega_integral)  # 0.15625 is 5 / 32
 
 
 def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
@@ -270,7 +314,10 @@ def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
         return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
                        * cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
                                                    molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
-                                                   molecule_num_rot1, molecule_num_rot2, False, False, False))
+                                                   molecule_num_rot1, molecule_num_rot2, False, False, False)
+                       + cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot2, Z_rot1, molecule_rot_symmetry2,
+                                                   molecule_rot_symmetry1, molecule_rot_const2, molecule_rot_const1,
+                                                   molecule_num_rot2, molecule_num_rot1, False, False, False))
         
         
 def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
@@ -317,52 +364,6 @@ def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc:
                                       molecule_rot_const, molecule_num_rot, False, False, False))
 
 
-def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: float, vsso: float, vssc_deflection: float,
-                         vsso_deflection: float, mass: float, n: float, infcoll: float, model: str='VSS') -> float:
-    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula,
-    *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    collision_mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    eps : float
-        the Lennard-Jones epsilon parameter :math:`\\varepsilon_{cd}`, divided by Boltzmann's constant
-    vssc : float
-        the :math:`C` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
-    vsso : float
-        the :math:`\\omega` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
-    vssc_deflection : float
-        the :math:`C` parameter for the VSS model for the deflection angle
-    vsso_deflection : float
-        the :math:`\\omega` parameter for the VSS model for the deflection angle
-    mass : float
-        the mass of the molecule for which the rotational relaxation time is being calculated
-    n : float
-        the numeric density of the mixture
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
-    model : str
-        the interaction model to be used, possible values:
-            * 'VSS' (Variable Soft Sphere model)
-            * 'VHS' (Variable Hard Sphere model)
-            * the Rigid Sphere model will be used otherwise
-
-        defaults to `'VSS'`
-
-    Returns
-    -------
-    float
-        Rotational relaxation time
-    """
-    return raw_Zr(T, collision_mass, eps, vsso, vssc_deflection, vsso_deflection, mass,
-                  infcoll, model) / ((vssc * n * ((8 * constants.k * T / (constants.pi * collision_mass)) ** 0.5)
-                                      * (T ** -vsso) * gamma(2 - vsso))
-                                     * (constants.physical_constants['Angstrom star'][0] ** 2))
-
-
 def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflection: float, vsso_deflection: float,
            mass: float, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models,
@@ -377,11 +378,11 @@ def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflec
     eps : float
         the Lennard-Jones :math:`\\varepsilon_{cd}` parameter of the molecule, divided by Boltzmann's constant
     vsso : float
-        the :math:`\\omega` parameter for the VSS model for the :math:`\\Omega^{(1,1)}` integral
+        the :math:`\\omega` parameter for the VSS model for the total cross-section
     vssc_deflection : float
         the :math:`C` parameter for the VSS model for the deflection angle
     vsso_deflection : float
-        the :math:`\\omega` parameter for the VSS model for the deflection angle
+        the :math:`\\omega` parameter for the VSS model for the crosssection
     mass : float
         the mass of the molecule for which the rotational relaxation time is being calculated
     infcoll : float
